@@ -13,12 +13,13 @@ our @ISA = qw(Exporter);
 # This allows declaration	use Linux::Unshare ':all';
 our %EXPORT_TAGS = ( 'clone' => [ qw(
 	CLONE_THREAD CLONE_FS CLONE_NEWNS CLONE_SIGHAND CLONE_VM CLONE_FILES CLONE_SYSVSEM
-	CLONE_CONTAINER CLONE_NEWNS CLONE_NEWUTS CLONE_NEWIPC CLONE_NEWNET CLONE_NEWPID CLONE_NEWUSER
+	CLONE_CONTAINER CLONE_NEWNS CLONE_NEWUTS CLONE_NEWIPC CLONE_NEWNET CLONE_NEWPID
+	CLONE_NEWUSER CLONE_NEWCGROUP
 ) ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'clone'} }, qw(unshare unshare_ns) );
 our @EXPORT = qw( );
 
-our $VERSION = '0.05';
+our $VERSION = '1.00';
 
 sub AUTOLOAD {
     my $constname;
